@@ -4,12 +4,18 @@ test_that("write_datasources works correctly", {
 
   # Setup
   valid_extensions <- c("yml", "yaml", "json", "rds")
-  temp_files <- purrr::map_chr(valid_extensions, ~ tempfile(fileext = paste0(".", .x))) |>
+  temp_files <- purrr::map_chr(
+    valid_extensions,
+    ~ tempfile(fileext = paste0(".", .x))
+  ) |>
     purrr::set_names(valid_extensions)
   temp_invalid <- tempfile(fileext = ".txt")
 
   # Test valid file extensions
-  purrr::walk(temp_files, ~ expect_no_error(write_datasources(test_connectors, .x)))
+  purrr::walk(
+    temp_files,
+    ~ expect_no_error(write_datasources(test_connectors, .x))
+  )
   # Test file content
   original_sources <- datasources(test_connectors)
   written_sources <- read_file(temp_files["yml"])
@@ -40,10 +46,13 @@ test_that("write_datasources works correctly", {
     )
   )
 
-  purrr::walk(invalid_inputs, ~ expect_error(
-    write_datasources(.x$input, .x$file),
-    .x$error
-  ))
+  purrr::walk(
+    invalid_inputs,
+    ~ expect_error(
+      write_datasources(.x$input, .x$file),
+      .x$error
+    )
+  )
 
   # Cleanup
   unlink(c(temp_files, temp_invalid))
